@@ -4,9 +4,10 @@ context("Fit ACi curves")
 
 # Load example dataset
 acidat <- droplevels(manyacidat[manyacidat$Curve %in% levels(manyacidat$Curve)[1:10],])
+acidatone <- droplevels(subset(acidat, Curve == "1000_2_3"))
+
 
 # Fit one A-Ci curve
-acidatone <- droplevels(subset(acidat, Curve == "1000_2_3"))
 fit1 <- fitaci(acidatone,  fitmethod="default")
 fit2 <- fitaci(acidatone,  fitmethod="bilinear")
 
@@ -15,6 +16,7 @@ fit3.1 <- fitaci(acidatone,  fitmethod="default", Tcorrect=TRUE, Tleaf=15)
 fit3.2 <- fitaci(acidatone,  fitmethod="default", Tcorrect=FALSE, Tleaf=15)
 fit3.3 <- fitaci(acidatone,  fitmethod="bilinear", Tcorrect=TRUE, Tleaf=15)
 fit3.4 <- fitaci(acidatone,  fitmethod="bilinear", Tcorrect=FALSE, Tleaf=15)
+fit3.5 <- fitaci(acidatone,  fitmethod="bilinear", Tcorrect=FALSE, fitTPU=TRUE)
 
 # With mesophyll conductance
 fit5 <- fitaci(acidatone,  fitmethod="default", gmeso=0.9)
@@ -36,8 +38,52 @@ fit8.4 <- fitaci(acidatone, useRd=TRUE, fitmethod="bilinear", Tcorrect=FALSE)
 fits1 <- fitacis(acidat, "Curve",  fitmethod="default", progressbar=FALSE)
 fits2 <- fitacis(acidat, "Curve",  fitmethod="bilinear", progressbar=FALSE)
 fits3 <- fitacis(acidat, "Curve",  fitTPU=TRUE, progressbar=FALSE)
+fits4 <- fitacis(acidat, "Curve",  fitmethod="bilinear", progressbar=FALSE, id="treatment")
+
+# one-point
+fit10.1 <- fitaci(acidatone, fitmethod = "onepoint")
+fit10.2 <- fitaci(acidatone, fitmethod = "onepoint", Tcorrect=FALSE)
+
+# Make some not fit
+acidat$Photo[c(2,50,100)] <- 50
+fits1_re <- fitacis(acidat, "Curve",  fitmethod="default", progressbar=FALSE)
+
+# Pass GammaStar, Km
+fit11 <- fitaci(acidatone, fitmethod="bilinear", GammaStar=60, Km=800)
+
+# Fit without PPFD, Tleaf
+# Set Rd but don't actually use
+acidatone$Tleaf <- acidatone$PARi <- NULL
+acidatone$Rd <- 2
+fit12 <- fitaci(acidatone, fitmethod="bilinear")
+
+
+fitaci(acidatone, citransition=400, fitmethod="default")
+
+
+print(fits4)
+print(fits3)
+print(fits2)
+print(fits1)
+
+print(fit1)
+print(fit2)
+print(fit3.1)
+print(fit3.2)
+
+summary(fit1)
+
+plot(fit1)
+plot(fit1, xlim=c(100,200), ylim=c(0,30), linecols="blue")
+plot(fit3.5)
+
+plot(fits1)
+plot(fits1, how="oneplot")
+
 
 test_that("Aci curve fit output format", {
+  expect_error(fitaci(data.frame()))
+  expect_length(fitted(fit1), nrow(acidatone))
   expect_equal(names(coef(fit1)), c("Vcmax","Jmax","Rd"))
   expect_equal(names(coef(fit2)), c("Vcmax","Jmax","Rd"))
   expect_equal(names(coef(fits1)), c("Curve","Vcmax","Jmax","Rd","Vcmax_SE","Jmax_SE","Rd_SE"))
@@ -48,6 +94,8 @@ test_that("Aci curve fit output format", {
   expect_s3_class(fit1, "acifit")
   expect_s3_class(fits1, "acifits")
   expect_gt(ncol(coef(fits3)), ncol(coef(fits2)))
+  expect_warning(fitacis(acidat, "Curve",  fitmethod="bilinear", progressbar=FALSE, id="XXXX"))
+  expect_true("treatment" %in% names(coef(fits4)))
 })
 
 test_that("Aci curve fitted coefficients",{
@@ -62,9 +110,9 @@ test_that("Aci curve fitted coefficients",{
 })
 
 test_that("Aci curve RMSE", {
-  expect_lt( max(sapply(fits1, "[[", "RMSE")), 5)
-  expect_lt( max(sapply(fits2, "[[", "RMSE")), 5)
-  expect_lt( max(sapply(fits3, "[[", "RMSE")), 5)
+  expect_lt( max(vapply(fits1, "[[", numeric(1), "RMSE")), 5)
+  expect_lt( max(vapply(fits2, "[[", numeric(1), "RMSE")), 5)
+  expect_lt( max(vapply(fits3, "[[", numeric(1), "RMSE")), 5)
   expect_lt(fit1$RMSE, 5)
   expect_lt(fit2$RMSE, 5)
   expect_lt(fit3.1$RMSE, 5)
